package de.intevation.flys.artifacts.model;

import de.intevation.flys.artifacts.cache.CacheFactory;

import de.intevation.flys.model.CrossSection;
import de.intevation.flys.model.CrossSectionLine;

import net.sf.ehcache.Cache;
import net.sf.ehcache.Element;

import java.util.List;


public class FastCrossSectionLineFactory
{
    public static final String CACHE_NAME = "fast-cross-section-lines";

    private FastCrossSectionLineFactory() {
    }

    public static FastCrossSectionLine getCrossSectionLine(
        CrossSection cs,
        double       km
    ) {
        Cache cache = CacheFactory.getCache(CACHE_NAME);

        if (cache == null) {
            List<CrossSectionLine> lines = cs.getLines(km, km);
            return lines.isEmpty()
                ? null
                : new FastCrossSectionLine(lines.get(0));
        }

        String cacheKey = FastCrossSectionChunk.createHashKey(cs, km);

        Element element = cache.get(cacheKey);

        FastCrossSectionChunk fcsc;

        if (element != null) {
            fcsc = (FastCrossSectionChunk)element.getValue();
        }
        else {
            fcsc = new FastCrossSectionChunk(cs, km);
            element = new Element(cacheKey, fcsc);
            cache.put(element);
        }

        return fcsc.getCrossSectionLine(km);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
